<?php
/**
 * Category Block One section
 *
 * This is the template for the content of Category Block One section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
*/

if ( ! function_exists( 'daily_insight_pro_add_category_block_one' ) ) :
    /**
     * Add Category Block One section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_category_block_one() {

        // Check if Category Block One is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $category_block_one_enable = (bool)( $options['enable_category_block_one'] );
        if ( true !== $category_block_one_enable ) {
            return false;
        }
        // Get Category Block One section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_category_block_one_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block One section .
        daily_insight_pro_render_category_block_one_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_category_block_one_action', 'daily_insight_pro_add_category_block_one', 10 );


if ( ! function_exists( 'daily_insight_pro_get_category_block_one_section_details' ) ) :
    /**
     * Category Block One section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Category Block One section details.
     */
    function daily_insight_pro_get_category_block_one_section_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Category Block One type
        $category_block_one_content_type    = $options['category_block_one_type'];
        $content = array();

        switch ( $category_block_one_content_type ) {

            case 'demo':
                $no_of_posts = 5; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'business-01.jpg', 'post-01.jpg', 'post-01.jpg','post-01.jpg', 'post-01.jpg', ); // An array of demo images
                $content[0]['terms']    = array( esc_html__( 'Financial','daily-insight-pro' ),esc_html__( 'Featured','daily-insight-pro' ) );
                $content[0]['excerpt']   = esc_html__('Nibh vel velit auctor aliquet. Aenean sollicitudin, lorem quis bibendum auctor, nisi elit consequat ipsum, nec sagittis sem nibh id elit .','daily-insight-pro');

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['date']      = 'Aug,03 2016';
                    $content[$index]['img_array'] = array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']       = '#';
                    $content[$index]['title']     = esc_html__('Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro');
                }
            break;

            case 'category':
              
                $category = !empty( $options['category_block_one_category_type'] ) ? absint( $options['category_block_one_category_type'] ) : '';

                if ( ! empty( $category ) ) {

                    $args = array(
                        'cat'            => $category,
                        'posts_per_page' => 5,
                    );
                }
                if( !empty( $args ) ) :

                    $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {
                            if( 0 === $index ) {
                                $img_array            = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-latest-post' );
                                $content[$index]['img_array'] = $img_array;
                            } 
                            else {
                                $img_array            = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'thumbnail' );
                                $content[$index]['img_array'] = $img_array;
                            }
                        }
                        $year  = get_the_time('Y', $custom_post->ID );
                        $month = get_the_time('m', $custom_post->ID );
                        $day   = get_the_time('d', $custom_post->ID );

                        $content[$index]['id']        = $custom_post->ID;
                        $content[$index]['date']      = get_the_date( '' , $custom_post );
                        $content[$index]['date_link'] = get_day_link( $year, $month, $day );
                        $content[$index]['title']     = get_the_title( $custom_post->ID );
                        $content[$index]['url']       = get_the_permalink( $custom_post->ID );
                        $content[$index]['terms']     = get_the_category( $custom_post->ID ); 
                        $content[0]['excerpt']        = daily_insight_pro_trim_content( 25, $custom_post );
                        $index++;
                    }
                endif;
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Category Block One section content details.
add_filter( 'daily_insight_pro_filter_category_block_one_section_details', 'daily_insight_pro_get_category_block_one_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_category_block_one_section' ) ) :
    /**
     * Start section Category Block One
     *
     * @return string Category Block One content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_category_block_one_section( $content_details = array() ) {

        $options       = daily_insight_pro_get_theme_options();
        $content_type  = $options['category_block_one_type'];
        $section_link  = get_category_link( $options['category_block_one_category_type'] );
        $section_title = get_cat_name( $options['category_block_one_category_type'] );
        $index         = 0;
        $count         = count( $content_details );

        if ( empty( $content_details ) ) {
            return;
        } 
    // Add a class for sidebar
        $sidebar_position = daily_insight_pro_layout();

        if ( is_active_sidebar( 'category_block_one_sidebar' ) && is_active_sidebar( 'sidebar-1' ) ) {
            $class = esc_attr( $sidebar_position );
        } elseif ( is_active_sidebar( 'category_block_one_sidebar' ) ){
            $class = esc_attr( $sidebar_position );
        } else {
            $class = 'no-sidebar';
        } ?>

        <section id="business-category-section" class="page-section <?php echo $class; ?> no-padding-bottom container two-columns">
            <div class="main-content">
            <?php 
            $section_title = ( $options['category_block_one_type'] == 'demo' ) ? esc_html__( 'Business','daily-insight-pro' ) : $section_title;
            $section_icon =  ( $options['category_block_one_type'] == 'demo' ) ? 'fa-laptop' : $options['category_block_one_icon'];
            $section_link =  ( $options['category_block_one_type'] == 'demo' ) ? esc_html__( '#','daily-insight-pro' ) : $section_link;

            if( ! empty ( $section_title ) ):?>
                <header class="entry-header clear">
                    <h2 class="entry-title category-title"><i class="fa <?php echo esc_attr( $section_icon ); ?>"></i><?php echo esc_html( $section_title ); ?></h2>  
                    <a href="<?php echo esc_url( $section_link ); ?>" class="view-more"><?php esc_html_e( 'View more','daily-insight-pro' ); ?></a>
                </header><!-- .entry-header -->
            <?php endif; ?>

                <div class="entry-content bg-white">
                    <div class="row">
                        <div class="column-wrapper">
                            <?php foreach( $content_details as $content ) : 
                                if( $index == 0 ) : 
                                    if( !empty( $content['img_array'][0] ) ) : ?>
                                        <div class="image-wrapper">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] );?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                            <div class="overlay"></div></a>
                                        </div><!-- .image-wrapper -->
                                <?php  endif;
                                else : 
                                    if( $index == 1 ) { 
                                        echo '<ul class="recent-posts">'; } 
                                    if( !empty( $content['img_array'][0] ) ) { 
                                        $class = ''; }
                                    else{ $class = 'no-post-thumbnail'; } ?>
                                    <li class="<?php echo $class; ?>">
                                        <?php if( !empty( $content['img_array'][0] ) ) { ?>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] );?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                                        </a>
                                        <?php } 
                                endif; ?>

                                <div class="post-wrapper">
                                    <div class="post-title">
                                        <h5><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h5>
                                        <?php if( $index == 0 ) : 
                                            $post_categories = $content['terms'];
                                            if( !empty ( $post_categories ) ) :
                                                if( 'demo' == $content_type ) { 
                                                    foreach ($post_categories as $post_category ) { ?>
                                                    <a class="category" href="#"><?php echo esc_html( $post_category ); ?></a>                        
                                                <?php } }
                                                else { 
                                                    foreach ( $post_categories as $post_category ) {
                                                        $category_id   = $post_category->term_id;
                                                        $category_name = $post_category->name;
                                                        $category_url  = get_category_link( $category_id );
                                                    ?>
                                                    <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a>
                                                <?php } }
                                            endif;
                                        endif; ?> 
                                    </div><!-- .post-title -->
                                    <?php if( $index == 0 ) : 
                                        if( !empty( $content['excerpt'] ) ) { ?>
                                        <div class="post-desc">
                                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                        </div><!-- .post-desc -->
                                    <?php }
                                        $readmore_text = ( $options['category_block_one_type'] == 'demo' ) ? esc_html__( 'Read More','daily-insight-pro' ) : $options['readmore_text'];
                                        if( !empty( $readmore_text ) ) : ?>
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="view-more"><?php echo esc_html( $readmore_text ); ?></a>
                                        <?php endif; ?>
                                        </div><!-- .post-wrapper -->
                                    </div><!-- .column-wrapper -->
                                    <div class="column-wrapper">
                                    <?php else : 
                                    $format = ( $options['category_block_one_type'] == 'demo' ) ? 'fa fa-camera' : daily_insight_pro_get_post_format_icon( $content['id'] ); // get post format icon
                                    $date_link = ( $options['category_block_one_type'] == 'demo' ) ? '#' : $content['date_link']; // get date archive link 
                                    ?>
                                            <a href="<?php echo esc_url( $date_link ); ?>"><time><i class="<?php echo esc_attr( $format ); ?>"></i><?php echo esc_html( $content['date'] ); ?></time></a>
                                        </div><!-- .post-wrapper -->
                                    </li>
                                        <?php if( ($count - 1) == $index ) {
                                            echo '</ul>' ;
                                        }
                                    endif; 
                            $index++; endforeach; ?>
                        </div><!-- .column-wrapper -->                        
                    </div><!-- .row -->
                </div><!-- .entry-content -->
            </div><!-- end .main-content -->

            <?php 
            if ( 'no-sidebar' != $class && is_active_sidebar( 'category_block_one_sidebar' ) ) { ?>
                <div class="section-sidebar">
                    <?php dynamic_sidebar( 'category_block_one_sidebar' ); ?>
                </div><!-- .section-sidebar -->
            <?php } ?>
        </section><!-- #business-ctegory-section -->

        <?php if ( is_active_sidebar( 'category_block_one_footer_sidebar' ) ) { ?>
        <section id="google-advertisement" class="container page-section">
            <?php dynamic_sidebar( 'category_block_one_footer_sidebar' ); ?>
        </section><!-- end .google-advertisement -->
        <?php }
    }
endif;