<?php

/**
 * Category Block Two Section One
 *
 * This is the template for the content of Category Block Two Section One. 
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_category_block_two_section_one' ) ) :
    /**
     * Add Category Block Two Section One
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_category_block_two_section_one() {  
    	// Check if Category Block Two Section One is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $category_block_two_section_one_enable = (bool)( $options['enable_category_block_two'] );
        if ( true !== $category_block_two_section_one_enable ) {
            return false;
        }
        // Get Category Block Two Section One section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_category_block_two_section_one_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block Two Section One section .
        daily_insight_pro_render_category_block_two_section_one( $section_details );
        
    }
endif;

if ( ! function_exists( 'daily_insight_pro_get_category_block_two_section_one_details' ) ) :
    /**
     * Category Block Two Section One section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Category Block Two Section One section details.
     */
    function daily_insight_pro_get_category_block_two_section_one_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Category Block Two Section One type
        $category_block_two_content_type = $options['category_block_two_type'];

        $content = array();

        switch ( $category_block_two_content_type ) {

            case 'demo':
                $no_of_posts = 4; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'technology-01.jpg', 'technology-02.jpg', 'technology-01.jpg','technology-02.jpg' ); // An array of demo images

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['date']     = 'Aug,03 2016';
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet.','daily-insight-pro' );
                    $content[$index]['excerpt']  = esc_html__( 'Ipsum proin gravida nibh vel velit auctor aliquet sollicitudin, lorem quis bibendum.','daily-insight-pro' );
                    $content[$index]['terms']    = esc_html__( 'Application','daily-insight-pro' );
                }
                        
                $input =  $content;
            break;

            case 'category':
            
                $no_of_posts = absint( $options['category_block_two_section_one_no_of_posts'] ) ;               
                $category = !empty( $options['category_block_two_section_one_category_type'] ) ? absint( $options['category_block_two_section_one_category_type'] ) : '';

                if ( ! empty( $category ) ) {

                    $args = array(
                        'cat'                 => $category,
                        'posts_per_page'      => $no_of_posts,
                    );
                }
                if( !empty( $args ) ) :

                    $custom_posts = get_posts( $args );

                    $index = 0;
                    foreach ( $custom_posts as $key => $custom_post ) {

                        if ( has_post_thumbnail( $custom_post->ID ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-category' );
                        } else {
                            $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-500x375.jpg' );
                    }

                    if ( isset( $img_array ) ) {
                        $content[$index]['img_array'] = $img_array;
                    }

                    $year  = get_the_time('Y', $custom_post->ID );
                    $month = get_the_time('m', $custom_post->ID );
                    $day   = get_the_time('d', $custom_post->ID );


                    $content[$index]['date_link'] = get_day_link( $year, $month, $day );
                    $content[$index]['date']      = get_the_date( '' , $custom_post );
                    $content[$index]['title']     = get_the_title( $custom_post->ID );
                    $content[$index]['url']       = get_the_permalink( $custom_post->ID );
                    $content[$index]['terms']     = get_the_category( $custom_post->ID ); 
                    $content[$index]['excerpt']   = daily_insight_pro_trim_content( 10, $custom_post );
                    $index++;
                    }
                endif;
            break;

            default:
            break;
        }
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Category Block Two Section One section content details.
add_filter( 'daily_insight_pro_filter_category_block_two_section_one_details', 'daily_insight_pro_get_category_block_two_section_one_details' );

if ( ! function_exists( 'daily_insight_pro_render_category_block_two_section_one' ) ) :
    /**
     * Start section Category Block Two Section One
     *
     * @return string Category Block Two Section One content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_category_block_two_section_one( $content_details = array() ) {

        $options = daily_insight_pro_get_theme_options();
        $content_type = $options['category_block_two_type'];
        $section_link = get_category_link( $options['category_block_two_section_one_category_type'] );
        $section_title = get_cat_name( $options['category_block_two_section_one_category_type'] );
        $index = 1;
        $zindex = 1;

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="technology-category" class="page-section">
        <?php 
        $section_title = ( $options['category_block_two_type'] == 'demo' ) ? esc_html__( 'Technology','daily-insight-pro' ) : $section_title;
        $section_icon =  ( $options['category_block_two_type'] == 'demo' ) ? 'fa-desktop' : $options['category_block_two_section_one_icon'];
        $section_link =  ( $options['category_block_two_type'] == 'demo' ) ? esc_html__( '#','daily-insight-pro' ) : $section_link;
            if( ! empty ( $section_title ) ) : ?>
            <header class="entry-header">
                <h2 class="entry-title category-title"><i class="fa <?php echo esc_attr( $section_icon ); ?>"></i><?php echo esc_html( $section_title ); ?></h2>  
                <a href="<?php echo esc_url( $section_link ); ?>" class="view-more"><?php esc_html_e('View more','daily-insight-pro' ); ?></a>
            </header><!-- .entry-header -->
            <?php endif; ?>

              <div class="entry-content">
                <div class="tabs-wrapper">
                    <?php foreach( $content_details as $content ) : 
                    $class = ($zindex == 1 ) ? 'active' : ''; ?>
                    <div id="tab-<?php echo $zindex; ?>" class="tab-content <?php echo $class; ?>">
                        <div class="post-category">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                            <div class="overlay"></div></a>
                            <div class="category-contents-wrapper">
                                <h2 class="title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2> 
                                <?php
                                $post_categories = $content['terms'];
                                if( !empty ( $post_categories ) ) :
                                    if( 'demo' == $content_type ) { ?>
                                        <a class="category" href="#"><?php echo esc_html( $post_categories ); ?></a>
                                        <a href="#"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                    <?php }
                                    else { 
                                        foreach ( $post_categories as $post_category ) {
                                            $category_id   = $post_category->term_id;
                                            $category_name = $post_category->name;
                                            $category_url  = get_category_link( $category_id );
                                        ?>
                                        <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a>
                                        <?php } ?>
                                        <a href="<?php echo esc_url( $content['date_link'] ); ?>"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                    <?php } 
                                endif;?>
                            </div><!-- .category-contents-wrapper -->
                        </div><!-- .post-category -->
                    </div><!-- #tab -->
                    <?php $zindex++; endforeach; ?>
                </div><!-- .tabs-wrapper -->

                <ul class="tabs">
                <?php foreach( $content_details as $content ) : 
                    $class = ($index == 1 ) ? 'active' : ''; ?>
                    <li class="tab-link <?php echo $class; ?>" data-tab="tab-<?php echo $index; ?>">
                        <h5><?php echo esc_html( $content['title'] ); ?></h5>
                        <?php if( !empty( $content['excerpt'] ) ) { echo '<p>'.esc_html( $content['excerpt'] ).'</p>'; } ?>
                    </li>
                <?php $index++; endforeach; ?>
                </ul>
            </div><!-- end .entry-content -->
        </section><!-- #technology-category -->
<?php
    }
endif;