<?php

/**
 * Main Slider section
 *
 * This is the template for the content of Main Slider section.
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_add_main_slider_section' ) ) :
    /**
     * Add Main Slider section
     *
     * @since Daily Insight Pro 1.0
     */
    function daily_insight_pro_add_main_slider_section() {

        // Check if Main SLider is enabled on frontpage
        $options = daily_insight_pro_get_theme_options(); 

        $main_slider_enable = apply_filters( 'daily_insight_pro_section_status', true, 'enable_main_slider' );
        if ( true !== $main_slider_enable ) {
            return false;
        }
        // Get Main SLider section details
        $section_details = array();
        $section_details = apply_filters( 'daily_insight_pro_filter_main_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Main SLider section .
        daily_insight_pro_render_main_slider_section( $section_details );
    }
endif;
add_action( 'daily_insight_pro_content_start_action', 'daily_insight_pro_add_main_slider_section', 40 );


if ( ! function_exists( 'daily_insight_pro_get_main_slider_section_details' ) ) :
    /**
     * Main SLider section details.
     *
     * @since Daily Insight Pro 1.0
     *
     * @param array $input Main SLider section details.
     */
    function daily_insight_pro_get_main_slider_section_details( $input ) {
        $options = daily_insight_pro_get_theme_options(); 

        // Main SLider type
        $main_slider_content_type    = $options['main_slider_type'];
        $no_of_posts = $options['main_slider_no_of_posts'];

        $content = array();

        switch ( $main_slider_content_type ) {

            case 'demo':
                $no_of_posts = 2; // Initialize and overwrite no of posts in demo by 3
                $images = array( 'slider-01.jpg', 'slider-01.jpg'); // An array of demo images
                $terms  = array( esc_html__( 'Lifestyle','daily-insight-pro' ), esc_html__( 'Lifestyle','daily-insight-pro' ) ); // An array of demo category

                for ( $index = 0; $index < $no_of_posts ; $index++ ) {
                    $content[$index]['date']     = 'Aug,03 2016';
                    $content[$index]['img_array']= array( get_template_directory_uri(). '/assets/uploads/'. $images[$index] );
                    $content[$index]['url']      = '#';
                    $content[$index]['title']    = esc_html__( 'Proin gravida nibh vel velit  auctor aliquet. Aenean sollicit.','daily-insight-pro' );
                    $content[$index]['terms']    = $terms[$index];
                }
                        
                $input =  $content;
            break;

            case 'category':
                $categories = array();
                $categories = !empty( $options['main_slider_category_type'] ) ? $options['main_slider_category_type'] : array();
                $category = array_filter( $categories );
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'category__in'      => $category,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $post_id    = ! empty ( $options['post_id_' . $i] ) ? absint( $options['post_id_' . $i] ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_posts,
                    );
                }
            break;

            case 'page':
                $page_list = array();
                for ( $i = 1; $i <= $no_of_posts ; $i++ ) { 
                    $page_id    = ! empty ( $options['page_id_' . $i] ) ? absint( $options['page_id_' . $i] ) : '';
                    $page_list  = array_merge( $page_list, array( $page_id ) );
                }

                if ( ! empty( $page_list ) ) {
                
                    $args = array(
                        'post_type'          => 'page',
                        'post__in'           => $page_list,
                        'posts_per_page'     => $no_of_posts,
                    );
                }
            break;

            default:
            break;          
        }
        if( $options['main_slider_type'] != 'demo'  ) :
            
            if( ! empty ( $args ) ) :
                $custom_posts = get_posts( $args );
        
                $i = 0;
                foreach ( $custom_posts as $key => $custom_post ) {
                    $img_array = null;

                    if ( has_post_thumbnail( $custom_post->ID ) ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'daily-insight-pro-main-slider' );
                    } else {
                            $img_array = array ( get_template_directory_uri() . '/assets/uploads/no-featured-image-1280x500.jpg' );
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $year  = get_the_time('Y', $custom_post->ID );
                    $month = get_the_time('m', $custom_post->ID );
                    $day   = get_the_time('d', $custom_post->ID );

                    $content[$i]['date_link'] = get_day_link( $year, $month, $day );
                    $content[$i]['url']       = get_permalink( $custom_post->ID );
                    $content[$i]['title']     = get_the_title( $custom_post->ID );
                    $content[$i]['terms']     = get_the_category( $custom_post->ID );
                    $content[$i]['date']      = get_the_date( '', $custom_post->ID );
                $i++;
                }
            endif;
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input; 
    }
endif;
// Main SLider section content details.
add_filter( 'daily_insight_pro_filter_main_slider_section_details', 'daily_insight_pro_get_main_slider_section_details' );

if ( ! function_exists( 'daily_insight_pro_render_main_slider_section' ) ) :
    /**
     * Start section Main SLider
     *
     * @return string Main SLider content
     * @since Daily Insight Pro 1.0
     *      
     */
    function daily_insight_pro_render_main_slider_section( $content_details = array() ) {

        $options = daily_insight_pro_get_theme_options();
        $content_type = $options['main_slider_type'];
        $slider_effect    = ( $options['main_slider_type'] == 'demo' ) ? 'cubic-bezier(0.250, 0.100, 0.250, 1.000)' : $options['slider_content_effect'];
        $slider_control   = ( $options['enable_slider_controls'] == true ) ? 'true' : 'false';
        $slider_dragable  = ( $options['enable_slider_dragable'] == true ) ? 'true' : 'false';
        $slider_pause     = ( $options['slider_pause_on_hover'] == true ) ? 'true' : 'false';

        if( $options['main_slider_type'] == 'demo' ) {
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": false }';
        }
        else{
            $data_slick_value = '{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "autoplay": true, "pauseOnHover":'. esc_attr( $slider_pause ).', "arrows":'.esc_attr( $slider_control ).',"draggable":'.esc_attr( $slider_dragable ).',"fade": false }';
        }

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="main-slider" class="page-section container" data-effect="<?php echo esc_attr( $slider_effect ); ?>" data-slick='<?php echo $data_slick_value; ?>' >
            <?php foreach( $content_details as $content ) : 
                if( !empty ($content['img_array'] ) ) : ?>
                    <div class="slider-item" style="background-image: url('<?php echo esc_url( $content['img_array'][0] ); ?>');">
                        <div class="overlay"></div>
                        <div class="main-slider-contents">
                            <h2 class="title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            <?php $post_categories = $content['terms'];
                            if( !empty ( $post_categories ) ) :
                                if( 'demo' == $content_type ) { ?>
                                    <a class="category" href="#"><?php echo esc_html( $post_categories ); ?></a>
                                    <a href="#"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                <?php }
                                else { 
                                    foreach ( $post_categories as $post_category ) {
                                        $category_id   = $post_category->term_id;
                                        $category_name = $post_category->name;
                                        $category_url  = get_category_link( $category_id );
                                    ?>
                                    <a class="category" href="<?php echo esc_url( $category_url ); ?>"><?php echo esc_html( $category_name ); ?></a>
                                <?php } ?>
                                <a href="<?php echo esc_url( $content['date_link'] ); ?>"><time><?php echo esc_html( $content['date'] ); ?></time></a>
                                <?php } 
                            endif; ?> 
                        </div><!-- .main-slider-contents -->
                    </div><!-- .slider-item -->
                <?php endif; 
            endforeach; ?>
        </section><!-- #main-slider -->
<?php
    }
endif;