<?php
/**
 * Daily Insight Pro widgets inclusion
 *
 * This is the template that includes all custom widgets of Daily Insight Pro
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function daily_insight_pro_register_sidebars() {

	register_sidebar( array(
		'name'          => esc_html__( 'Header Right', 'daily-insight-pro' ),
		'id'            => 'header_ad_image_widget',

		'description'   => esc_html__( 'This is the header right widget area. This widget area is not equipped to display any widget, and works best with a search form, social icons widget, Advertisement Widget or possibly a text widget.', 'daily-insight-pro' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Category Block One Sidebar', 'daily-insight-pro' ),
		'id'            => 'category_block_one_sidebar',
		'description'   => esc_html__( 'This widget area is for category block one sidebar widget. Widgets will be visible only when category blog one is enabled from customizer section', 'daily-insight-pro' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget-header"><h4 class="widget-title">',
		'after_title'   => '</h4></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Category Block One Footer Sidebar', 'daily-insight-pro' ),
		'id'            => 'category_block_one_footer_sidebar',
		'description'   => esc_html__( 'This widget area is for advertisement widget. This widget area will be visible below category block one section. Recommended image size is 1180x160 px.', 'daily-insight-pro' ),
		'before_widget' => '<div id="%1$s" class="widget-wrap %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Category Block Two Footer Sidebar', 'daily-insight-pro' ),
		'id'            => 'category_block_two_footer_sidebar',
		'description'   => esc_html__( 'This widget area is for advertisement widget on category block two section and recommended to use Ad Image widgets here. Widgets will be visible only when category blog two is enabled from customizer section', 'daily-insight-pro' ),
		'before_widget' => '<section id="%1$s" class="widget-wrap %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
	
	for ($i=1; $i <= 4 ; $i++) {
		register_sidebar( array(
			'name'          => sprintf( esc_html__( 'Footer %s', 'daily-insight-pro' ), $i ),
			'id'            => 'footer-'.$i,
			'description'   => sprintf( esc_html__( 'Footer %s widget area.', 'daily-insight-pro' ), $i ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );
	}
}
add_action( 'widgets_init', 'daily_insight_pro_register_sidebars' );

/*
 * Add social link widget
 */
require get_template_directory() . '/inc/widgets/social-link.php';
/*
 * Add Ad image widget
 */
require get_template_directory() . '/inc/widgets/ad-image.php';
/*
 * Add video widget
 */
require get_template_directory() . '/inc/widgets/video-widget.php';
/*
 * Add Contact info widget
 */
require get_template_directory() . '/inc/widgets/contact-info.php';
/*
 * Add instagram widget
 */
require get_template_directory() . '/inc/widgets/instagram.php';
/*
 * Add popular post meta
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-meta.php';
/*
 * Add popular post widget
 */
require get_template_directory() . '/inc/widgets/popular-post/popular-post-widget.php';
/*
 * Add custom recent comments widget
 */
require get_template_directory() . '/inc/widgets/custom-recent-comments.php';
/*
 * Add custom recent comments widget
 */
require get_template_directory() . '/inc/widgets/counter-widget.php';
/*
 * Add custom category widget
 */
require get_template_directory() . '/inc/widgets/custom-category-widget.php';

/*
 * Add gallery slider widget
 */
require get_template_directory() . '/inc/widgets/gallery-slider-widget.php';

/*
 * Add tab widget
 */
require get_template_directory() . '/inc/widgets/tab-widget.php';

/*
 * Add post slider widget
 */
require get_template_directory() . '/inc/widgets/post-slider.php';